//cc -g -o edwin edwin4.c -I ../.. ../../perms.c -lm

#ifndef __EDWIN4_H__
#define __EDWIN4_H__ 1
extern int Uinfi(int Parm);
extern void Console(int Fn, int *A, int *L);
extern void Messages(_imp_string State);
extern void Maptodevicecoords(int *X, int *Y);
extern void Maptovirtualcoords(int *X, int *Y);
extern void Initialisefor(int Type);
extern void Terminateedwin(void);
extern void Lineabs(int X, int Y);
extern void Moveabs(int X, int Y);
extern void Markerabs(int N, int X, int Y);
extern void Linerel(int X, int Y);
extern void Moverel(int X, int Y);
extern void Markerrel(int N, int X, int Y);
extern void Character(int Ch);
extern void Text(_imp_string St);
extern void Newframe(void);
extern void Update(void);
extern void Clipon(void);
extern void Clipoff(void);
extern void Storeon(int Stream);
extern void Storeoff(void);
extern void Viewon(int Stream);
extern void Viewoff(void);
extern void Window(int A, int B, int C, int D);
extern void Viewport(int A, int B, int C, int D);
extern void Setcolour(int To);
extern void Setlinestyle(int To);
extern void Setcharsize(int To);
extern void Setcharrot(int To);
extern void Setcharquality(int To);
extern void Setcharfont(int To);
extern void Setcharslant(int To);
extern void Setintensity(int To);
extern void Setspeed(int To);
extern void Aspectratioing(int Mode);
extern void Inquireposition(int *X, int *Y);
extern void Inquirewindow(int *A, int *B, int *C, int *D);
extern void Inquireviewport(int *A, int *B, int *C, int *D);
extern void Review(void);
#endif
