int _imp_mainep(int _imp_argc, char **_imp_argv) {
  static const int Pdfstream = 2;
  static const int Good = 1;
  int I;
  int X;
  int Y;
  Newframe();
  Storeon(Pdfstream);
  Moveabs(400, 20);
  for (I = 1; I <= 4; I++) {
    Moverel(-36, 0);
    Linerel(-36, 0);
  }
  Linerel(0, 720);
  for (I = 1; I <= 4; I++) {
    Moverel(36, 0);
    Linerel(36, 0);
  }
  for (I = 1; I <= 4; I++) {
    Linerel(0, -720);
    Linerel(-36, 0);
    Linerel(0, 720);
    Linerel(-36, 0);
  }
  for (I = 1; I <= 6; I++) {
    Moverel(0, -60);
    Linerel(288, 0);
    Moverel(0, -60);
    Linerel(-288, 0);
  }
  X = 112;
  Y = 697;
  Moveabs(X, Y);
  I = 32;
  Setcharsize(36);
  Setcharquality(Good);
  for (;;) {
    Markerrel(4, 0, 0);
    Character(I);
    I++;
    if (I == 127) break;
    if (X == 364) {
      Markerrel(4, 0, 0);
      Y -= 60;
      X = 112;
    } else
      X += 36;
    Moveabs(X, Y);
  }
  Terminateedwin();
  exit(0);
  return (1);
}
